==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/SegmentDeliveryConfiguration.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class SegmentDeliveryConfiguration(
    baseUrl: Option[__string] = None,
    name: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.SegmentDeliveryConfiguration = {
    import SegmentDeliveryConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.SegmentDeliveryConfiguration
      .builder()
      .optionallyWith(
        baseUrl.map(value => __string.unwrap(value): java.lang.String)
      )(_.baseUrl)
      .optionallyWith(
        name.map(value => __string.unwrap(value): java.lang.String)
      )(_.name)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.SegmentDeliveryConfiguration.ReadOnly =
    zio.aws.mediatailor.model.SegmentDeliveryConfiguration.wrap(buildAwsValue())
}
object SegmentDeliveryConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.SegmentDeliveryConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.SegmentDeliveryConfiguration =
      zio.aws.mediatailor.model.SegmentDeliveryConfiguration(
        baseUrl.map(value => value),
        name.map(value => value)
      )
    def baseUrl: Option[__string]
    def name: Option[__string]
    def getBaseUrl: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("baseUrl", baseUrl)
    def getName: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("name", name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.SegmentDeliveryConfiguration
  ) extends zio.aws.mediatailor.model.SegmentDeliveryConfiguration.ReadOnly {
    override val baseUrl: Option[__string] = scala
      .Option(impl.baseUrl())
      .map(value => zio.aws.mediatailor.model.primitives.__string(value))
    override val name: Option[__string] = scala
      .Option(impl.name())
      .map(value => zio.aws.mediatailor.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.SegmentDeliveryConfiguration
  ): zio.aws.mediatailor.model.SegmentDeliveryConfiguration.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.17.158.3-sources.jar: zio/aws/mediatailor/model/SegmentDeliveryConfiguration.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class SegmentDeliveryConfiguration(
    baseUrl: Option[__string] = None,
    name: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.SegmentDeliveryConfiguration = {
    import SegmentDeliveryConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.SegmentDeliveryConfiguration
      .builder()
      .optionallyWith(baseUrl.map(value => value: java.lang.String))(_.baseUrl)
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.SegmentDeliveryConfiguration.ReadOnly =
    zio.aws.mediatailor.model.SegmentDeliveryConfiguration.wrap(buildAwsValue())
}
object SegmentDeliveryConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.SegmentDeliveryConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.SegmentDeliveryConfiguration =
      zio.aws.mediatailor.model.SegmentDeliveryConfiguration(
        baseUrl.map(value => value),
        name.map(value => value)
      )
    def baseUrl: Option[__string]
    def name: Option[__string]
    def getBaseUrl: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("baseUrl", baseUrl)
    def getName: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("name", name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.SegmentDeliveryConfiguration
  ) extends zio.aws.mediatailor.model.SegmentDeliveryConfiguration.ReadOnly {
    override val baseUrl: Option[__string] =
      scala.Option(impl.baseUrl()).map(value => value: __string)
    override val name: Option[__string] =
      scala.Option(impl.name()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.SegmentDeliveryConfiguration
  ): zio.aws.mediatailor.model.SegmentDeliveryConfiguration.ReadOnly =
    new Wrapper(impl)
}
